@@ -26,6 +26,7 @@
 #include "arpackobject.h"
 #include "attributes.h"
 #include "bfsiter.h"
+#include "dfsiter.h"
 #include "common.h"
 #include "convert.h"
 #include "edgeobject.h"
@@ -36,6 +37,7 @@
 #include "random.h"
 #include "vertexobject.h"
 #include "vertexseqobject.h"
+#include "operators.h"
 
 #define IGRAPH_MODULE
 #include "igraphmodule_api.h"
@@ -650,6 +652,18 @@ static PyMethodDef igraphmodule_methods[] =
     METH_VARARGS | METH_KEYWORDS,
     "_split_join_distance(comm1, comm2)"
   },
+  {"_disjoint_union", (PyCFunction)igraphmodule__disjoint_union,
+    METH_VARARGS | METH_KEYWORDS,
+    "_disjoint_union(graphs)"
+  },
+  {"_union", (PyCFunction)igraphmodule__union,
+    METH_VARARGS | METH_KEYWORDS,
+    "_union(graphs, edgemaps)"
+  },
+  {"_intersection", (PyCFunction)igraphmodule__intersection,
+    METH_VARARGS | METH_KEYWORDS,
+    "_intersection(graphs, edgemaps)"
+  },
   {NULL, NULL, 0, NULL}
 };
 
@@ -657,7 +671,7 @@ static PyMethodDef igraphmodule_methods[] =
   "Low-level Python interface for the igraph library. " \
   "Should not be used directly.\n\n"                    \
   "@undocumented: community_to_membership, _compare_communities, _power_law_fit, " \
-  "_split_join_distance"
+  "_split_join_distance, _union, _intersection, _disjoint_union"
 
 /**
  * Module definition table (only for Python 3.x)
@@ -764,6 +778,8 @@ extern PyObject* igraphmodule_arpack_options_default;
     INITERROR;
   if (PyType_Ready(&igraphmodule_BFSIterType) < 0)
     INITERROR;
+  if (PyType_Ready(&igraphmodule_DFSIterType) < 0)
+    INITERROR;
   if (PyType_Ready(&igraphmodule_ARPACKOptionsType) < 0)
     INITERROR;
 
@@ -783,6 +799,7 @@ extern PyObject* igraphmodule_arpack_options_default;
   /* Add the types to the core module */
   PyModule_AddObject(m, "GraphBase", (PyObject*)&igraphmodule_GraphType);
   PyModule_AddObject(m, "BFSIter", (PyObject*)&igraphmodule_BFSIterType);
+  PyModule_AddObject(m, "DFSIter", (PyObject*)&igraphmodule_DFSIterType);
   PyModule_AddObject(m, "ARPACKOptions", (PyObject*)&igraphmodule_ARPACKOptionsType);
   PyModule_AddObject(m, "Edge", (PyObject*)&igraphmodule_EdgeType);
   PyModule_AddObject(m, "EdgeSeq", (PyObject*)&igraphmodule_EdgeSeqType);
