@@ -120,20 +120,26 @@ class BasicTests(unittest.TestCase):
         self.assertEqual(
             sorted(g.vertex_attributes()), ["ham", "name", "spam"]
         )
-        self.assertEqual(g.vs["spam"], [None]*4 + ["cheese"])
-        self.assertEqual(g.vs["ham"], [None]*4 + [42])
+        self.assertEqual(g.vs["spam"], [None] * 4 + ["cheese"])
+        self.assertEqual(g.vs["ham"], [None] * 4 + [42])
 
     def testAddVertices(self):
         g = Graph()
         g.add_vertices(2)
         self.assertTrue(g.vcount() == 2 and g.ecount() == 0)
+
         g.add_vertices("spam")
         self.assertTrue(g.vcount() == 3 and g.ecount() == 0)
         self.assertEqual(g.vs[2]["name"], "spam")
+
         g.add_vertices(["bacon", "eggs"])
         self.assertTrue(g.vcount() == 5 and g.ecount() == 0)
         self.assertEqual(g.vs[2:]["name"], ["spam", "bacon", "eggs"])
 
+        g.add_vertices(2, attributes={'color': ['k', 'b']})
+        self.assertEqual(g.vs[2:]["name"], ["spam", "bacon", "eggs", None, None])
+        self.assertEqual(g.vs[5:]["color"], ["k", "b"])
+
     def testDeleteVertices(self):
         g = Graph([(0, 1), (1, 2), (2, 3), (0, 2), (3, 4), (4, 5)])
         self.assertEqual(6, g.vcount())
@@ -172,6 +178,10 @@ class BasicTests(unittest.TestCase):
         self.assertRaises(ValueError, g.delete_vertices, "no-such-vertex")
         self.assertRaises(InternalError, g.delete_vertices, 2)
 
+        # Delete all vertices
+        g.delete_vertices()
+        self.assertEqual(0, g.vcount())
+
     def testAddEdge(self):
         g = Graph()
         g.add_vertices(["spam", "bacon", "eggs", "ham"])
@@ -208,6 +218,14 @@ class BasicTests(unittest.TestCase):
             (0, 1), (1, 2), (2, 3), (1, 3), (0, 2), (0, 3)
         ])
 
+        g.add_edges([(0, 0), (1, 1)], attributes={'color': ['k', 'b']})
+        self.assertEqual(g.get_edgelist(), [
+            (0, 1), (1, 2), (2, 3), (1, 3), (0, 2), (0, 3), (0, 0), (1, 1),
+        ])
+        self.assertEqual(
+            g.es['color'],
+            [None, None, None, None, None, None, 'k', 'b'])
+
     def testDeleteEdges(self):
         g = Graph.Famous("petersen")
         g.vs["name"] = list("ABCDEFGHIJ")
@@ -260,6 +278,21 @@ class BasicTests(unittest.TestCase):
         self.assertRaises(ValueError, g.delete_edges, [("A", "C")])
         self.assertRaises(ValueError, g.delete_edges, [(0, 15)])
 
+        # Delete all edges
+        g.delete_edges()
+        self.assertEqual(0, g.ecount())
+
+    def testClear(self):
+        g = Graph.Famous("petersen")
+        g["name"] = list("petersen")
+
+        # Clearing the graph
+        g.clear()
+
+        self.assertEqual(0, g.vcount())
+        self.assertEqual(0, g.ecount())
+        self.assertEqual([], g.attributes())
+
     def testGraphGetEid(self):
         g = Graph.Famous("petersen")
         g.vs["name"] = list("ABCDEFGHIJ")
